﻿using System.Collections.Generic;
using System.Collections.ObjectModel;

namespace GroupEditorPrototype
{
    public class MainWindowViewModel : ViewModelBase
    {
        public void Initialize()
        {
            _schemas = SetupSchemas();
            _assets = SetupAssets();

            OnPropertyChanged(nameof(Schemas));
            OnPropertyChanged(nameof(Assets));
        }

		private ObservableCollection<Schema> _schemas;
		public ObservableCollection<Schema> Schemas
		{
			get => _schemas;
			set => SetProperty(ref _schemas, value);
		}

        private ObservableCollection<GroupingItem> _assets;
        public ObservableCollection<GroupingItem> Assets
        {
            get => _assets;
            private set => SetProperty(ref _assets, value);
        }

		/* BEGIN MOCK DATA SETUP CODE  */
        private ObservableCollection<Schema> SetupSchemas()
        {
            var children = new List<Schema>();

			for (var i = 0; i < 5; i++)
			{
				var child = new Schema { Name = $"Schema-{i + 1}", IsExpanded = true };
				for (var j = 0; j < 5; j++)
				{
					var childGroup = new Group { Name = $"Group-{i + 1}-{j}", IsExpanded = false, ParentGroup = child.Name };
					for (var k = 0; k < 3; k++)
					{
						var childDevice = new Device { Name = $"Device-{i + j + 1}-{k}", ParentGroup = childGroup.Name };
						childGroup.Children.Add(childDevice);
					}
					child.Children.Add(childGroup);
				}				
				children.Add(child);
			}

            return new ObservableCollection<Schema>(children);
        }

        private ObservableCollection<GroupingItem> SetupAssets()
        {
            var children = new List<GroupingItem>();

			for (var i = 0; i < 10; i++)
			{
				var child = new AssetNode { Name = $"Node-Lv{i + 1}-{i + 1}", IsExpanded = false };
				for (var j = 0; j < 10; j++)
				{
					var childDevice = new Device { Name = $"Device{j + 1}-{i + 1}" };
					child.Children.Add(childDevice);
				}
				children.Add(child);
			}

			for (var i = 0; i < 10; i++)
			{
				var childDevice = new Device { Name = $"Device{i + 11}" };
				children.Add(childDevice);
			}
			return new ObservableCollection<GroupingItem>(children);
		}
		/* END MOCK DATA SETUP CODE  */
	}
}
